@@ -7,25 +7,28 @@ use serde::{Deserialize, Serialize};
 use std::{fs::read_to_string, io::Result, path::Path};
 use validators::{crypto, internet, network, system};
 
+/// All different types of artifacts that which can be found in a given string
 #[derive(Serialize, Deserialize, Default, Debug, Clone)]
-pub struct Indicators {
-    /// All found URLs
+pub struct Artifacts {
+    /// All found URLs in the given string
     pub urls: Option<Vec<String>>,
-    /// All found Domains
+    /// All found Domains in the given string
     pub domains: Option<Vec<String>>,
-    /// All found Email Addresses
+    /// All found Email Addresses in the given string
     pub emails: Option<Vec<String>>,
-    /// All found IP Addresses
+    /// All found IP Addresses in the given string
     pub ip_address: Option<Vec<String>>,
-    /// All found Crypto Addresses
+    /// All found Crypto Addresses in the given string
     pub crypto: Option<Vec<String>>,
-    /// All found Registry Keys
+    /// All found Registry Keys in the given string
     pub registry_keys: Option<Vec<String>>,
-    /// All found SQL Statements
+    /// All found SQL Statements in the given string
     pub sql: Option<Vec<String>>,
+    /// All found Regular Expressions in the given string
+    pub regexes: Option<Vec<String>>,
 }
 
-pub fn from_file<P: AsRef<Path>>(file: P) -> Result<Option<Indicators>> {
+pub fn from_file<P: AsRef<Path>>(file: P) -> Result<Option<Artifacts>> {
     //! Extracts Indicators from a given file
     //!
     //! ## Example Usage
@@ -39,7 +42,7 @@ pub fn from_file<P: AsRef<Path>>(file: P) -> Result<Option<Indicators>> {
     Ok(from_str(&f))
 }
 
-pub fn from_str(s: &str) -> Option<Indicators> {
+pub fn from_str(s: &str) -> Option<Artifacts> {
     //! Extracts Indicators from a given string
     //!
     //! ## Example Usage
@@ -56,12 +59,12 @@ pub fn from_str(s: &str) -> Option<Indicators> {
     let mut crypto_address = vec![];
     let mut registry = vec![];
     let mut sql = vec![];
+    let mut regexes = vec![];
 
     // Create a default Indicator object
-    let mut iocs = Indicators::default();
+    let mut iocs = Artifacts::default();
 
     // check for registry keys & sql queries by breaking only newlines
-    // let sr = s.split('\n').collect::<Vec<&str>>();
     for x in s.split('\n').collect::<Vec<&str>>() {
         if system::is_registry_key(x) {
             registry.push(x.to_string())
@@ -71,7 +74,6 @@ pub fn from_str(s: &str) -> Option<Indicators> {
     }
 
     // check for the rest by breaking newlines, whitespace, tabs, etc...
-    // let s = s.split_whitespace().collect::<Vec<&str>>();
     for x in s.split_whitespace().collect::<Vec<&str>>() {
         if network::is_ipv_any(x) || network::is_ip_cidr_any(x) {
             ip_address.push(x.to_string())
@@ -83,6 +85,8 @@ pub fn from_str(s: &str) -> Option<Indicators> {
             urls.push(x.to_string())
         } else if internet::is_email(x, None) {
             emails.push(x.to_string())
+        } else if system::is_regex(x) {
+            regexes.push(x.to_string())
         }
     }
 
@@ -93,6 +97,7 @@ pub fn from_str(s: &str) -> Option<Indicators> {
         && crypto_address.is_empty()
         && registry.is_empty()
         && sql.is_empty()
+        && regexes.is_empty()
     {
         return None;
     }
@@ -133,6 +138,12 @@ pub fn from_str(s: &str) -> Option<Indicators> {
         iocs.sql = Some(sql);
     }
 
+    if !regexes.is_empty() {
+        regexes.sort();
+        regexes.dedup();
+        iocs.regexes = Some(regexes);
+    }
+
     // return the result object
     Some(iocs)
 }
